#include <bsta/algo/bsta_adaptive_updater.h>
#include <bsta/algo/bsta_bayes_functor.h>
#include <bsta/algo/bsta_beta_updater.h>
#include <bsta/algo/bsta_fit_gaussian.h>
#include <bsta/algo/bsta_fit_weibull.h>
#include <bsta/algo/bsta_gaussian_stats.h>
#include <bsta/algo/bsta_gaussian_updater.h>
#include <bsta/algo/bsta_mean_shift.h>
#include <bsta/algo/bsta_mixture_functors.h>
#include <bsta/algo/bsta_parzen_updater.h>
#include <bsta/algo/bsta_sample_set.h>
#include <bsta/algo/bsta_truth_updater.h>
#include <bsta/algo/bsta_von_mises_updater.h>

int main() { return 0; }
